%%  Within array normalization
%  Comparison of alternative procedures to increase within array consistency
%  
%  
%% Calculation
%  The calculations rely heavily on a new command:
help internal_consistency
%  It Accesses differences within pairs and between top and bottom pairs
%  This function takes into account that some ESTs (a surprising number for Javier's arrays)
%  are ploted in more than one pair. However, the bottom half of the
%  microarray will have as many pairs as the top. The core function tests
%  for that and uses the added number of combinations. The comparisons are
%  never performed for average values, all combinations are considered.
%% Raw data
%  Application to Javier's 5 replicates
mic=mgma_get([221,222,223,133,134])
%% Unprocessed Intensities
%  
Co=internal_consistency(mic(1)) % collecting Ids of comparisons
if exist('C');clear C;end
for i=1:length(mic)
    C(i)=internal_consistency(mic(i),Co,ma_filter2(mic(i)));
end
%  *Conclusion*: there are much, much larger differences between top vs
%  bottom pairs that between adjacent spots ( in the same pair) 
%% Effect of local background subtraction
k1=strmatch('ch1 Intensity',mic(1).ColumnNames);k2=strmatch('ch1 Background',mic(1).ColumnNames);
for i=1:length(mic)
    m=mic(i);m.Data(:,k1)=m.Data(:,k1)-m.Data(:,k2);
    Cb(i)=internal_consistency(mic(i),Co,ma_filter2(m));
    disp(['for MG# ',num2str(m.id),' Local background subtraction causes'])
    disp(['Right vs Left to go from Spearman''s ',num2str(C(i).stats.rSp),' to ',num2str(Cb(i).stats.rSp)])
    disp(['Bottom vs Top to go from Spearman''s ',num2str(C(i).stats.Sp),' to ',num2str(Cb(i).stats.Sp)])
end
%  *Conclusion*: local background subtraction has a small but consistent beneficial effect. 
%  This implies we need to find a stronger correction for spacial heterogeneity in the hybridization response
%% Global background correction - by sliding medians
%  this correction works by deiving each value by the median within a
%  certain window. for example, for the last array, the matrix of
%  intensities, M, is:
M=zeros(size(m.Indices));M(:)=m.Data(:,k1);
close all;subplot(1,2,1);imagesc(M);colorbar;title('intensity')
subplot(1,2,2);imagesc(sliding_median(M,16,16));colorbar;title('median intensity within 16x16')
M=M./sliding_median(M,16,16);figure;imagesc(M);title('Median corrected array')
%% Determination of optimal window size
%Let's do it for a single array first, say the last replicate in the series
i=0;j=0;close all
xx=[8:8:64];yy=[8:16:64];
for i=1:length(xx)
    x=xx(i);
    for j=1:length(yy)
        y=yy(j);
        Mm=M./sliding_median(M,x,y);
        Mmemb=sliding_memb(M,x,y);
        %figure;imagesc(Mm);colorbar;title(['Sliding window of ',num2str(x),'x',num2str(y)])
        Cm=internal_consistency(m,Co,Mm(:));close all
        rSp(i,j)=Cm.stats.rSp;Sp(i,j)=Cm.stats.Sp;
        Cmemb=internal_consistency(m,Co,Mmemb(:));close all
        rSp_memb(i,j)=Cm.stats.rSp;Sp_memb(i,j)=Cm.stats.Sp;
    end
end
disp(rSp)
disp(Sp)
disp(rSp_memb)
disp(Sp_memb)
close all;
subplot(1,2,1);imagesc(rSp);title('Spearman''s Right vs Left\newline(sliding median)')
subplot(1,2,2);imagesc(Sp);title('Spearman''s Bottom vs Top\newline(sliding median)')
figure
subplot(1,2,1);imagesc(rSp_memb);title('Spearman''s Right vs Left\newline(sliding quantile)')
subplot(1,2,2);imagesc(Sp_memb);title('Spearman''s Bottom vs Top\newline(sliding quantile)')
%% Annex 1 - code for internal_consistency
type internal_consistency
%% Annex 2 - code for sliding_median
type sliding_median