function [s,cubo_calc,cubo_raw]=cvsenso(ann,xo)

% function [s,cubo_calc,cubo_raw]=cvsenso(ann,xo)
% Calculates the sensitivity of the neural network net (format NETLAB)
% to the input variables xo, the average values are stored n "s"
% if xo is not provided it will use the ann input data
%
% the sensitivity is measured as (In/Out)*(d.Out/d.In)
% the raw values are stored in the 3D matrix CUBO
%
% NOTE: version of cvsensa that calculates sensitivities algebraically
%       Jonas Sept 2001

if nargin<2;xo=ann.x.x;end

[nx,mx]=size(xo);

w1=-[ann.net.w1;ann.net.b1]';
w2=-[ann.net.w1;ann.net.b1]';


1/(1+exp(w2/(1+exp(w1*x))))^2*w2/(1+exp(w1*x))^2*w1*exp(w1*x)*exp(w2/(1+exp(w1*x)))

FUNCTION INCOMPLETE !!!!!!!

yo=cvpreve(ann,xo);
% anna(xo,w1,w2,mmx,mmy);

[ny,my]=size(yo);

cubo_raw=zeros(nx,mx,my); % raw sensitivities
cubo_calc=zeros(mx,my,4); % treated sensitivities, outputs vs inputs
x1=zeros(1,mx);
x2=zeros(1,mx);
y1=zeros(1,my);
y2=zeros(1,my);
dx=0.001*(ann.x.mm(2,:)-ann.x.mm(1,:)); % step changes in the input variables

for i=1:nx
   for ii=1:mx
      x1=xo(i,:);
      x2=x1;
      x1(1,ii)=x1(1,ii)-0.5*dx(1,ii);
      x2(1,ii)=x1(1,ii)+0.5*dx(1,ii);
      dx21=x2-x1;
      y1=cvpreve(ann,x1);
      % anna(x1,w1,w2,mmx,mmy);
      y2=cvpreve(ann,x2);
      % anna(x2,w1,w2,mmx,mmy);
      dy21=y2-y1;
      for iii=1:my
          cubo_raw(i,ii,iii)=(xo(i,ii)/yo(i,iii))*(dy21(1,iii)/dx21(1,ii)); %(In/Out)*(d.Out/d.In)
      end
   end
end

% Average sensitivity positive or negative(first layer)

for i=1:mx
   for ii=1:my
      cubo_calc(i,ii,1)=mean(abs(cubo_raw(:,i,ii)));
   end
end

% Maximum sensitivity, positive or negative (second layer)

for i=1:mx
   for ii=1:my
      mais=max(cubo_raw(:,i,ii));
      menos=min(cubo_raw(:,i,ii));
      if abs(menos)>abs(mais)
         cubo_calc(i,ii,2)=menos;
      else
         cubo_calc(i,ii,2)=mais;
      end
   end
end

% Cummulative average sensitivity

sums=sum(abs(cubo_calc(:,:,1)));
for i=1:mx
   for ii=1:my
      cubo_calc(i,ii,3)=cubo_calc(i,ii,1)/sums(ii);
   end
end

% Cummulative maximum sensitivity

sums=sum(abs(cubo_calc(:,:,2)));
for i=1:mx
   for ii=1:my
      cubo_calc(i,ii,4)=cubo_calc(i,ii,2)/sums(ii);
   end
end

% The average sensitivities only

s=cubo_calc(:,:,3);
